summaryrefslogtreecommitdiff
path: root/test/units
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2022-11-10 17:33:31 +0100
committerLennart Poettering <lennart@poettering.net>2022-11-10 17:33:51 +0100
commit63b130a6fcf6029c2a96e61b03912e78b1f9c6b0 (patch)
tree62c6a5bfe74eca305916a09031cdd2060f68862b /test/units
parent71ea84369e458eb6b4f4664dd7daa47bc96c7d32 (diff)
downloadsystemd-63b130a6fcf6029c2a96e61b03912e78b1f9c6b0.tar.gz
test: add quick test for ensuring image UUID is deterministic based on the seed passed to repart
Diffstat (limited to 'test/units')
-rwxr-xr-xtest/units/testsuite-58.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/test/units/testsuite-58.sh b/test/units/testsuite-58.sh
index 8787a24c0e..5a515d9c01 100755
--- a/test/units/testsuite-58.sh
+++ b/test/units/testsuite-58.sh
@@ -769,9 +769,10 @@ EOF
roothash=$(jq -r ".[] | select(.type == \"root-${architecture}-verity\") | .roothash" <<< "$output")
# Check that we can dissect, mount and unmount a repart verity image.
systemd-dissect "$imgs/verity" --root-hash "$roothash"
+ systemd-dissect "$imgs/verity" --root-hash "$roothash" --json=short | grep -q '"imageUuid":"1d2ce291-7cce-4f7d-bc83-fdb49ad74ebd"'
systemd-dissect "$imgs/verity" --root-hash "$roothash" -M "$imgs/mnt"
systemd-dissect -U "$imgs/mnt"
}
@@ -769,9 +769,10 @@ EOF
roothash=$(jq -r ".[] | select(.type == \"root-${architecture}-verity\") | .roothash" <<< "$output")
- # Check that we can dissect, mount and unmount a repart verity image.
+ # Check that we can dissect, mount and unmount a repart verity image. (and that the image UUID is deterministic)
systemd-dissect "$imgs/verity" --root-hash "$roothash"